*Autor: Sergio Urzua
*Fecha: 3 de Enero 2010 

clear
set more 1
set mem 1500m
pause on

cd "/Users/Sergio/Documents/Hacienda/TallerdeVerano/Lunes3Enero/Ejemplo_CASEN/"

use casen2009_25sampleF.dta, clear

*Guarda resultados en archivo resultados.txt
log using Resultados.txt, text replace

drop if nucleo==0			/*Habilitar en caso de calcular pobreza*/

/* Generacion de Variable: Identificacion de hogares*/

sort region provincia comuna zona segmento idviv hogar 
egen Fam_ID=group(region provincia comuna zona segmento idviv hogar)

/* Generacion de Variables: Ejemplo es educacion*/

/*
Descripcion de la variable e7t:

           1 educacin preescolar o educacin parvularia
           2 preparatoria (sistema antiguo)
           3 educacin bsica
           4 educacin diferencial
           5 humanidades (sistema antiguo)
           6 educacin media cientfico-humanstica
           7 tcnica, comercial, industrial o normalista (sistema antiguo
           8 educacin media tcnica profesional
           9 centro de formacin tcnica incompleta (sin ttulo)
          10 centro de formacin tcnica completa ( con ttulo)
          11 instituto profesional incompleta (sin ttulo)
          12 instituto profesional completa (con ttulo)
          13 educacin universitaria incompleta (sin ttulo)
          14 educacin universitaria completa (con ttulo)
          15 universitaria de postgrado
          16 ninguno
*/


*Generando anios de escolaridad
gen esc_g=.
replace esc_g=0 if e7t==4
replace esc_g=0 if e7t==1
replace esc_g=e7c if e7t==2
replace esc_g=e7c if e7t==3
replace esc_g=e7c +8 if e7t==6
replace esc_g=e7c +6 if e7t==5
replace esc_g=e7c +6 if e7t==7
replace esc_g=e7c +8 if e7t==8
replace esc_g=e7c +12 if e7t==9
replace esc_g=e7c +12 if e7t==10
replace esc_g=e7c +12 if e7t==11
replace esc_g=e7c +12 if e7t==12
replace esc_g=e7c +12 if e7t==13
replace esc_g=e7c +12 if e7t==14
replace esc_g=e7c +12 if e7t==15
replace esc_g=0 if e7t==16

corr esc_g esc  /*chequeando nueva variable. Mideplan nos ayuda.*/

/*********************/
/*ANALISIS DE POBREZA*/
/*********************/

/* Primer paso: INGRESOS*/

/* Generacion de Variables: Ingreso per capital del hogar*/

gen i_ingpc=ytothaj/numper
gen i_autpc=yauthaj/numper
gen i_subpc=ysubhaj/numper
gen i_alqpc=yaimhaj/numper

gen p_aut=(yauthaj/ytothaj)
gen p_sub=(ysubhaj/ytothaj)
gen p_alq=(yaimhaj/ytothaj)

/* Segundo paso: Lineas de pobreza e indigencia*/

*Linea pobreza
gen     lin_pob=64134 if z==1
replace lin_pob=43242 if z==2

*Linea indigencia
gen     lin_ind=32067 if z==1
replace lin_ind=24710 if z==2

*Variable pobreza
gen pobre=0
replace pobre=1 if i_ingpc<lin_pob

*Variable indigencia
gen indigente=0
replace indigente=1 if i_ingpc<lin_ind

*Estadisticas pobreza e indigencia
tab pobre indigente
tab pobre indigente, col row
tab pobre indigente [w=expr], col row

tab corte /*Variable ya existente en la base*/
tab corte pobre /*Podemos chequear nuestra construccion*/
tab corte indigente 

/* Tercer paso: Identificacion de hogares con caracteristicas particulares*/

*Genera dummy: 1(hombre >= 65 anio o mujer >= 60 anio) 0(otro caso)
gen amayor=((edad>=60 & sexo==2) | (edad>=65 & sexo==1))

*Indicada si en una familia hay individuos con caracteristicas defininas en amayor
egen h_amayor=max(amayor), by(Fam_ID)

*Genera dummy: 1(edad<=5) 0(otro caso)
gen nino5=(edad<=5)
*Indicada si en una familia hay individuos con caracteristicas defininas en nino5
egen h_nino5=sum(nino5), by(Fam_ID)

/*Cuarto paso: Generacion de Tramos de Edad*/

gen EDAD=20 if edad<=20
replace EDAD=25 if edad>20 & edad<=25
replace EDAD=30 if edad>25 & edad<=30
replace EDAD=35 if edad>30 & edad<=35
replace EDAD=40 if edad>35 & edad<=40
replace EDAD=45 if edad>40 & edad<=45
replace EDAD=50 if edad>45 & edad<=50
replace EDAD=55 if edad>50 & edad<=65

/*Quinto paso: Generacion de condiciones de ocupacion*/

gen participation=.
replace participation=0 if EDAD>=15 /*Asumimos poblacion ed edad de trabajar >=15*/
replace participation=1 if EDAD>=15 & (activ==1 | activ==2)

*Indica participacion laboral femenina (empleo o desempleo)
gen participationF=.
replace participationF=0 if EDAD>=15 & sexo==2
replace participationF=1 if EDAD>=15 & (activ==1 | activ==2)  & sexo==2

gen empleo=.
replace empleo=0 if EDAD>=15 & (activ==3 | activ==2)
replace empleo=1 if EDAD>=15 & (activ==1)

*Indica empleo femenino
gen empleoF=.
replace empleoF=0 if EDAD>=15 & sexo==2 & (activ==3 | activ==2)
replace empleoF=1 if EDAD>=15 & (activ==1)  & sexo==2

/*Sexto paso: Generacion de percentiles y quintiles*/

*Genera percentil de ingreso total del hogar
xtile perc_ing = ytotaj if ytotaj!=. [w=expr], nq(100)

*Genera quintil de ingreso total del hogar
xtile quint_ing = ytotaj if ytotaj!=. [w=expr], nq(5)

tab quint_ing [w=expr]

/*RESULTADOS*/

*Ingreso promedio por quintiles de ingreso
graph bar ytotaj [w=expr] if perc_ing<26, medtype(line) over(perc_ing) ytitle(Pesos) ///
title("Ingreso promedio", size(medsmall) color(black) justification(center)) ///
subtitle("por percentil de ingreso, 2009", size(medsmall) color(black) justification(center)) ///
note("Fuente:CASEN2009.", span)  
graph save "G1.gph", replace
graph export "G1.eps", replace mag(175) orientation(landscape)  fontface(Garamond)   

pause

*Distribucion de ingreso
graph box ytotaj [w=expr] if perc_ing<26, medtype(line) over(perc_ing) ytitle(Pesos) ///
title("Distribucion de ingreso", size(medsmall) color(black) justification(center)) ///
subtitle("por percentil de ingreso, 2009", size(medsmall) color(black) justification(center)) ///
note("Fuente: CASEN2009.", span)
graph save "G2.gph", replace
graph export "G2.eps", replace mag(175) orientation(landscape)  fontface(Garamond)   

pause

*Edad Promedio" "por decil de ingreso per-capita
graph bar EDAD [w=expr], over(quint_ing)  ///
title("Edad Promedio" "por decil de ingreso per-capita") ///
ytitle(Edad) ///
note("Fuente: CASEN2009.", span)  
graph save "G3.gph", replace
graph export "G3.eps", replace mag(175) orientation(landscape)  fontface(Garamond)   

pause

*Anios de escolaridad por quintil de ingreso
graph bar esc [w=expr], medtype(line) over(quint_ing) ytitle(Escolaridad) ///
title("Educacion Promedio", size(medsmall) color(black) justification(center)) ///
subtitle("por percentil de ingreso, 2009", size(medsmall) color(black) justification(center)) ///
note("Fuente: MIDEPLAN en base a CASEN2009.", span)
graph save "G4.gph", replace
graph export "G4.eps", replace mag(175) orientation(landscape)  fontface(Garamond)

pause

*Distribucion de anios de escolaridad

graph box esc [w=expr], medtype(line) over(quint_ing) ytitle(Escolaridad) ///
title("Distribucion de la Educacion", size(medsmall) color(black) justification(center)) ///
subtitle("por percentil de ingreso, 2009", size(medsmall) color(black) justification(center)) ///
note("Fuente: MIDEPLAN en base a CASEN2009.", span)
graph save "G5.gph", replace
graph export "G5.eps", replace mag(175) orientation(landscape)  fontface(Garamond)

pause

*Empleo sobre fuerza laboral (%)

graph bar empleo [w=expr] if perc_ing<20, medtype(line) over(perc_ing) ytitle(%) ///
title("Tasa de Empleo", size(medsmall) color(black) justification(center)) ///
subtitle("por percentil de ingreso, 2009", size(medsmall) color(black) justification(center)) ///
note("Fuente: CASEN2009.", span) 
graph save "G6.gph", replace
graph export "G6.eps", replace mag(175) orientation(landscape)  fontface(Garamond)

pause

*Empleo femenino sobre fuerza laboral (%)

graph bar empleoF [w=expr] if perc_ing<20, medtype(line) over(perc_ing) ytitle(%)  ///
title("Tasa de Empleo Femenina", size(medsmall) color(black) justification(center)) ///
subtitle("por percentil de ingreso, 2009", size(medsmall) color(black) justification(center)) ///
note("Fuente: CASEN2009.", span)
graph save "G7.gph", replace
graph export "G7.eps", replace mag(175) orientation(landscape)  fontface(Garamond)

/*Analisis de Regresion*/

*Variable dependiente
gen logY=log(ytotaj)

*Variable dicotmica, 1(mujer) 0 (hombre)
replace sexo=sexo-1

*Regresion OLS asumiendo anios de escolaridad como variable continua
regress logY esc edad sexo 

*Regresion OLS asumiendo anios de escolaridad como variable categorica
xi: regress logY i.esc edad sexo 

/*El analisis a nivel del hogar*/

*Promedio variables a nivel de hogar y organizo datos como hogar=fila

collapse (mean) i_ingpc (mean) numper (mean) expr (mean) participation (mean) empleo (mean) empleoF (mean) EDAD ///
(sum) amayor (sum) nino5 (mean) pobre (mean) z ///
(mean) i_autpc (mean) i_subpc (mean) i_alqpc (mean) esc, by(Fam_ID) 

*Percentiles y quintiles de ingreso per capita, por hogar

xtile perc_ingpc = i_ingpc if i_ingpc!=. [w=expr], nq(100)
xtile deci_ingpc = i_ingpc if i_ingpc!=. [w=expr], nq(10)


*Distribucion de ingreso per capita del Hogar, por percentil de ingreso per capita del hogar

graph box i_ingpc [w=expr] if perc_ingpc<26, medtype(line) over(perc_ingpc) ytitle(Pesos) ///
yline(64134, lcolor(gs12) lstyle(grid)  lpattern(dash)) ///
text(64134 80 "LP (U)", place(n)) ///
yline(50000, lcolor(gs8) lstyle(grid) lpattern(dash)) ///
text(50000 80 "IMF", place(n)) ///
yline(32067, lcolor(gs2) lstyle(grid) lpattern(dash)) ///
text(32067 80 "LP (R)", place(n)) ///
title("Distribucion de ingreso per capita del Hogar", size(medsmall) color(black) justification(center)) ///
subtitle("por percentil de ingreso per capita del hogar, 2009", size(medsmall) color(black) justification(center)) ///
note("Fuente: MIDEPLAN en base a CASEN2009.", span)
graph save "G8.gph", replace
graph export "G8.eps", replace mag(175) orientation(landscape)  fontface(Garamond)   
 
 pause
 
*Ingreso per capita promedio del hogar, por percentil de ingreso per capita del hogar 

graph bar i_ingpc [w=expr] if perc_ingpc<26, medtype(line) over(perc_ingpc) ytitle(Pesos) ///
yline(64134, lcolor(gs12) lstyle(grid)  lpattern(dash)) ///
text(64134 4 "LP (U)", place(n)) ///
yline(50000, lcolor(gs8) lstyle(grid) lpattern(dash)) ///
text(50000 4 "IMF", place(n)) ///
yline(32067, lcolor(gs2) lstyle(grid) lpattern(dash)) ///
text(32067 4 "LP (R)", place(n)) ///
title("Ingreso per capita promedio del hogar", size(medsmall) color(black) justification(center)) ///
subtitle("por percentil de ingreso per capita del hogar, 2009", size(medsmall) color(black) justification(center)) ///
note("Fuente: MIDEPLAN en base a CASEN2009.", span)  
graph save "G9.gph", replace
graph export "G9.eps", replace mag(175) orientation(landscape)  fontface(Garamond)   

pause

*Descomposicion del Ingreso per capita Promedio del hogar, por percentil de ingreso per capita del hogar

graph bar (mean) i_autpc i_subpc i_alqpc [w=expr] if perc_ingpc<20, medtype(line) over(perc_ingpc) ytitle(Pesos) ///
legend(label(1 "Autonomo") label(2 "Subsidios") label(3 "Alquiler imputado")) ///
asyvars stack legend(caption(Fuente de Ingresos:, position(12))) ///
yline(64134, lcolor(gs12) lstyle(grid)  lpattern(dash)) ///
text(64134 4 "LP (U)", place(n)) ///
yline(50000, lcolor(gs8) lstyle(grid) lpattern(dash)) ///
text(50000 4 "IMF", place(n)) ///
yline(32067, lcolor(gs2) lstyle(grid) lpattern(dash)) ///
text(32067 4 "LP (R)", place(n)) ///
title("Descomposicion del Ingreso per capita Promedio del hogar",  size(medsmall) color(black) justification(center)) ///
subtitle("por percentil de ingreso per capita del hogar, 2009", size(medsmall) color(black) justification(center)) ///
note("Fuente: MIDEPLAN en base a CASEN2009.", span)  
graph save "G10.gph", replace
graph export "G10.eps", replace mag(175) orientation(landscape)  fontface(Garamond)

*Cierre de archivo resultados.txt
log close
